@@ -13,7 +13,7 @@ from optparse import OptionParser, OptionGroup
 
 from PIL import Image as PImage
 
-__version__ = '0.2.6'
+__version__ = '0.2.7'
 
 
 PADDING_REGEXP = re.compile("^(\d+-?){,3}\d+$")
@@ -50,7 +50,7 @@ DEFAULT_SETTINGS = {
     'cachebuster': False,
     'cachebuster-filename': False,
     'global_template':
-        ('%(all_classes)s{background-image:url(%(sprite_url)s);'
+        ('%(all_classes)s{background-image:url(\'%(sprite_url)s\');'
          'background-repeat:no-repeat}\n'),
     'each_template':
         ('%(class_name)s{background-position:%(x)s %(y)s;'
@@ -61,7 +61,7 @@ DEFAULT_SETTINGS = {
          'only screen and (min--moz-device-pixel-ratio: %(ratio)s), '
          'only screen and (-o-min-device-pixel-ratio: %(ratio_fraction)s), '
          'only screen and (min-device-pixel-ratio: %(ratio)s) {'
-         '%(all_classes)s{background-image:url(%(sprite_url)s);'
+         '%(all_classes)s{background-image:url(\'%(sprite_url)s\');'
          '-webkit-background-size: %(width)s %(height)s;'
          '-moz-background-size: %(width)s %(height)s;'
          'background-size: %(width)s %(height)s;'
@@ -520,7 +520,7 @@ class Image(object):
     @cached_property
     def _padding_info(self):
         """Return the padding information from the filename."""
-        for block in self.filename.split('_')[::-1]:
+        for block in self.filename.split('_')[:0:-1]:
             if PADDING_REGEXP.match(block):
                 return  block.split('-')
         return []
@@ -878,7 +878,7 @@ class Sprite(object):
                               self.manager.output_path('css'))
 
         if self.config.url:
-            url = os.path.join(self.config.url, '%s.png' % self.filename)
+            url = os.path.join(self.config.url, url)
 
         if self.config.cachebuster:
             url = "%s?%s" % (url, self.cachebuster_hash)
@@ -1294,11 +1294,6 @@ def main():
         parser.error(("You must choose between using an unique output dir, or "
                       "using --css and --img."))
 
-    if options.optipng and not command_exists(options.optipngpath):
-        parser.error("'optipng' seems to be unavailable. You need to "
-                     "install it before using --optipng, or "
-                     "provide a path using --optipngpath.")
-
     source = os.path.abspath(args[0])
     output = os.path.abspath(args[1]) if len(args) == 2 else None
 
@@ -1319,6 +1314,11 @@ def main():
     config = ConfigManager(config, priority=options, defaults=DEFAULT_SETTINGS)
     manager = manager_cls(path=source, output=output, config=config)
 
+    if config.optipng and not command_exists(config.optipngpath):
+        parser.error("'optipng' seems to be unavailable. You need to "
+                     "install it before using --optipng, or "
+                     "provide a path using --optipngpath.")
+
     if manager.config.watch:
         WatchManager(path=source, action=manager.process).run()
         sys.exit(0)
